@@ -1,5 +1,5 @@
 import re
-from typing import Optional
+from typing import Optional, List
 
 from . import dates_regex
 
@@ -17,7 +17,7 @@ class DatesParser:
         """
         self.generic_re = regex_for_dates or dates_regex.generic_re
 
-    def extract_all_dates(self, text: str) -> list[str]:
+    def extract_all_dates(self, text: str) -> List[str]:
         """
         Extract dates only and returns list of dates
         :param text: cv to parse
@@ -28,7 +28,7 @@ class DatesParser:
             extracted_dates.append(match.group())
         return extracted_dates
 
-    def extract_dates_sections(self, text) -> list[dict]:
+    def extract_dates_sections(self, text) -> List[dict]:
         """
         Extract dates with descriptions found in cv
         :param text: cv to parse
@@ -36,6 +36,7 @@ class DatesParser:
         """
         previous_date_end = None
         previous_date = None
+        previous_date_span = None
         dates_with_description = []
         for match in self.generic_re.finditer(text.lower()):
             next_date_start = match.span()[0]
@@ -43,17 +44,18 @@ class DatesParser:
                 dates_with_description.append({
                     "date": previous_date,
                     "description": text[previous_date_end:next_date_start],
-                    "span": match.span(),
+                    "span": previous_date_span,
                     "description_span": (previous_date_end, next_date_start)
                 })
             previous_date = match.group()
-            previous_date_end = match.span()[1]
+            previous_date_span = match.span()
+            previous_date_end = previous_date_span[1]
         if previous_date:
             dates_with_description.append({
                 "date": previous_date,
                 "description": text[previous_date_end:],
-                "span": previous_date_end,
-                "description_span": (previous_date_end)
+                "span": previous_date_span,
+                "description_span": (previous_date_end, None)
             })
         return dates_with_description
 
